==> zio-aws-serverlessapplicationrepository_2.12-5.17.124.1-sources.jar: zio/aws/serverlessapplicationrepository/model/GetCloudFormationTemplateRequest.scala <==
package zio.aws.serverlessapplicationrepository.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.serverlessapplicationrepository.model.primitives.__string
import scala.jdk.CollectionConverters._
final case class GetCloudFormationTemplateRequest(
    applicationId: __string,
    templateId: __string
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.serverlessapplicationrepository.model.GetCloudFormationTemplateRequest = {
    import GetCloudFormationTemplateRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.serverlessapplicationrepository.model.GetCloudFormationTemplateRequest
      .builder()
      .applicationId(__string.unwrap(applicationId): java.lang.String)
      .templateId(__string.unwrap(templateId): java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.serverlessapplicationrepository.model.GetCloudFormationTemplateRequest.ReadOnly =
    zio.aws.serverlessapplicationrepository.model.GetCloudFormationTemplateRequest
      .wrap(buildAwsValue())
}
object GetCloudFormationTemplateRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.serverlessapplicationrepository.model.GetCloudFormationTemplateRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.serverlessapplicationrepository.model.GetCloudFormationTemplateRequest =
      zio.aws.serverlessapplicationrepository.model
        .GetCloudFormationTemplateRequest(applicationId, templateId)
    def applicationId: __string
    def templateId: __string
    def getApplicationId: ZIO[Any, Nothing, __string] =
      ZIO.succeed(applicationId)
    def getTemplateId: ZIO[Any, Nothing, __string] = ZIO.succeed(templateId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.serverlessapplicationrepository.model.GetCloudFormationTemplateRequest
  ) extends zio.aws.serverlessapplicationrepository.model.GetCloudFormationTemplateRequest.ReadOnly {
    override val applicationId: __string =
      zio.aws.serverlessapplicationrepository.model.primitives
        .__string(impl.applicationId())
    override val templateId: __string =
      zio.aws.serverlessapplicationrepository.model.primitives
        .__string(impl.templateId())
  }
  def wrap(
      impl: software.amazon.awssdk.services.serverlessapplicationrepository.model.GetCloudFormationTemplateRequest
  ): zio.aws.serverlessapplicationrepository.model.GetCloudFormationTemplateRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-serverlessapplicationrepository_2.12-5.17.201.1-sources.jar: zio/aws/serverlessapplicationrepository/model/GetCloudFormationTemplateRequest.scala <==
package zio.aws.serverlessapplicationrepository.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.serverlessapplicationrepository.model.primitives.__string
import scala.jdk.CollectionConverters._
final case class GetCloudFormationTemplateRequest(
    applicationId: __string,
    templateId: __string
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.serverlessapplicationrepository.model.GetCloudFormationTemplateRequest = {
    import GetCloudFormationTemplateRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.serverlessapplicationrepository.model.GetCloudFormationTemplateRequest
      .builder()
      .applicationId(applicationId: java.lang.String)
      .templateId(templateId: java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.serverlessapplicationrepository.model.GetCloudFormationTemplateRequest.ReadOnly =
    zio.aws.serverlessapplicationrepository.model.GetCloudFormationTemplateRequest
      .wrap(buildAwsValue())
}
object GetCloudFormationTemplateRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.serverlessapplicationrepository.model.GetCloudFormationTemplateRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.serverlessapplicationrepository.model.GetCloudFormationTemplateRequest =
      zio.aws.serverlessapplicationrepository.model
        .GetCloudFormationTemplateRequest(applicationId, templateId)
    def applicationId: __string
    def templateId: __string
    def getApplicationId: ZIO[Any, Nothing, __string] =
      ZIO.succeed(applicationId)
    def getTemplateId: ZIO[Any, Nothing, __string] = ZIO.succeed(templateId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.serverlessapplicationrepository.model.GetCloudFormationTemplateRequest
  ) extends zio.aws.serverlessapplicationrepository.model.GetCloudFormationTemplateRequest.ReadOnly {
    override val applicationId: __string = impl.applicationId(): __string
    override val templateId: __string = impl.templateId(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.serverlessapplicationrepository.model.GetCloudFormationTemplateRequest
  ): zio.aws.serverlessapplicationrepository.model.GetCloudFormationTemplateRequest.ReadOnly =
    new Wrapper(impl)
}
